<template>
  <a-card :bordered="false">

    <!-- 操作按钮区域 -->
    <div class="table-operator" :md="24" :sm="24" style="margin: -25px 0px 10px 0px">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>

      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel">
            <a-icon type="delete"/>
            删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作
          <a-icon type="down"/>
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>
          <a-divider type="vertical"/>
          <a-dropdown>
            <a class="ant-dropdown-link">
              更多 <a-icon type="down"/>
            </a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a href="javascript:;" @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
    </div>
    <!-- table区域-end -->
    <!-- 表单区域 -->
    <lims-prod-model-modal  ref="modalForm" @ok="modalFormOk"></lims-prod-model-modal>
  </a-card>
</template>

<script>
import {JeecgListMixin} from '@/mixins/JeecgListMixin'
import {getAction} from '@/api/manage'
import LimsProdModelModal from '@views/limsTest/modules/LimsProdModelModal'

export default {
  name: "ProductModelList",
  mixins: [JeecgListMixin],
  components: {
    LimsProdModelModal

  },
  data() {
    return {
      description: '产品型号',
      disableMixinCreated:true,
      // 表头
      columns: [
        {
          title: '型号编码',
          align: "center",
          width: 100,
          dataIndex: 'modelCode',
          key: 'modelCode',
        },
        {
          title: '型号名称',
          align: "center",
          width: 100,
          dataIndex: 'modelName',
        },
        {
          title: '通道数',
          align: "center",
          dataIndex: 'channelNum',
        },
        {
          title: '前缀',
          dataIndex: 'prefix',
          align: "center",
        },
        {
          title: '描述',
          dataIndex: 'description',
          align: "center",
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy_dictText'
        },
        {
          title: '创建时间',
          align: 'center',
          dataIndex: 'createTime'
        },  {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy_dictText'
        },
        {
          title: '更新时间',
          align: 'center',
          dataIndex: 'updateTime'
        },
        {
          title: '操作',
          key: 'operation',
          align: 'center',
          width: 130,
          scopedSlots: {customRender: 'action'},
        },
      ],
      url: {
        list: "/lims/testing/pmodel/list",
        delete: "/lims/testing/pmodel/delete",
        edit: "/lims/testing/pmodel/edit",
        deleteBatch: "/lims/testing/pmodel/deleteBatch",
      }
    }
  },
  methods: {
    loadData(arg) {
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      //update-begin--Author:kangxiaolin  Date:20190905 for：[442]主子表分开维护，生成的代码子表的分页改为真实的分页--------------------
      var params = this.getQueryParams();
      getAction(this.url.list, {prodId: params.prodId, pageNo : this.ipagination.current,
        pageSize :this.ipagination.pageSize}).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records;
          this.ipagination.total = res.result.total;
        } else {
          this.dataSource = null;
        }
      })
      //update-end--Author:kangxiaolin  Date:20190905 for：[442]主子表分开维护，生成的代码子表的分页改为真实的分页--------------------

    },
    /**
     * 根据产品id查询产品型号
     * @param prodId
     */
    getProductModelList(prodId) {
      this.queryParam.prodId = prodId;
      this.loadData(1);
    },
    handleAdd: function () {
      if(!this.queryParam.prodId){
        this.$message.error('请选择一个产品!')
        return false
      }
      this.$refs.modalForm.add(this.queryParam.prodId);


    },
    modalFormOk(){
      //添加成功后reload
      this.queryParam.prodId = this.queryParam.prodId;
      this.loadData(1);
    }
  }
}
</script>
<style scoped>
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
</style>